# Olympict

![coverage](https://gitlab.com/gabraken/olympict/badges/master/coverage.svg?job=tests)![status](https://gitlab.com/gabraken/olympict/badges/master/pipeline.svg)

![Olympict](https://gitlab.com/gabraken/olympict/-/raw/master/Olympict.png)


This project will make image processing pipelines 
easy to use using the basic multiprocessing module. This module uses type checking to ensure your data process validity from the start.

